<?php

/**
 * Kopano iCal class.
 *
 * @category   apps
 * @package    kopano
 * @subpackage libraries
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2010-2011 Tim Burgess
 * @copyright  2011-2016 ClearFoundation
 * @license    http://www.gnu.org/copyleft/lgpl.html GNU Lesser General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/kopano/
 */

///////////////////////////////////////////////////////////////////////////////
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// N A M E S P A C E
///////////////////////////////////////////////////////////////////////////////

namespace clearos\apps\kopano;

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// T R A N S L A T I O N S
///////////////////////////////////////////////////////////////////////////////

clearos_load_language('kopano');

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

use \clearos\apps\base\Daemon as Daemon;
use \clearos\apps\base\File as File;
use \clearos\apps\network\Network_Utils as Network_Utils;

clearos_load_library('base/Daemon');
clearos_load_library('base/File');
clearos_load_library('network/Network_Utils');

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Kopano iCal class.
 *
 * @category   apps
 * @package    kopano
 * @subpackage libraries
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2010-2011 Tim Burgess
 * @copyright  2011-2016 ClearFoundation
 * @license    http://www.gnu.org/copyleft/lgpl.html GNU Lesser General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/kopano/
 */

class Kopano_iCal extends Daemon
{
    ///////////////////////////////////////////////////////////////////////////////
    // C O N S T A N T S
    ///////////////////////////////////////////////////////////////////////////////

    const FILE_KOPANO_ICAL = '/etc/kopano/ical.cfg';

    ///////////////////////////////////////////////////////////////////////////////
    // M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////

    /**
     * Kopano constructor.
     */

    function __construct()
    {
        clearos_profile(__METHOD__, __LINE__);

        parent::__construct('kopano-ical');
    }

    /**
     * Returns configured iCal port for given service.
     *
     * @param string $service service name
     *
     * @return integer port number
     * @throws Engine_xXception, Validation_Exception
     */

    public function get_port($service)
    {
        clearos_profile(__METHOD__, __LINE__);

        $file = new File(self::FILE_KOPANO_ICAL);

        $port = $file->lookup_value("/^${service}_listen\s*=\s*/i");
        $port = preg_replace('/.*:/', '', trim($port));

        return $port;
    }

    /**
     * Returns state of iCal service.
     *
     * @param string $service service name
     *
     * @return boolean state of iCal service.
     * @throws Engine_Exception, Validation_Exception
     */

    public function get_state($service)
    {
        clearos_profile(__METHOD__, __LINE__);

        $file = new File(self::FILE_KOPANO_ICAL);

        $state = $file->lookup_value("/^${service}_enable\s+/i");
        $state = trim($state);

        if (preg_match('/yes/i', $state))
            return TRUE;
        else
            return FALSE;
    }

    /**
     * Sets ical port.
     *
     * @param integer $port port number
     *
     * @return void
     * @throws Engine_Exception, Validation_Exception
     */

    public function set_port($service, $port)
    {
        clearos_profile(__METHOD__, __LINE__);

        $key = $service . '_listen';

        if ( ! empty($port)) 
            $port = "*:".$port;

        $file = new File(self::FILE_KOPANO_ICAL);
        $match = $file->replace_lines("/^$key\s+/i", "$key = $port\n");

        if (! $match)
            $file->add_lines_after("$key = $port\n", "/^[^#]/");
    }

    /**
     * Sets ical service state.
     *
     * @param string  $service service
     * @param boolean $state   state
     *
     * @return void
     * @throws Engine_Exception, Validation_Exception
     */

    public function set_state($service, $state)
    {
        clearos_profile(__METHOD__, __LINE__);

        $file = new File(self::FILE_KOPANO_ICAL);
        $key = $service . "_enable";
        $state_value = ($state) ? 'yes' : 'no';

        $match = $file->replace_lines("/^$key\s+/i", "$key = $state_value\n");

        if (! $match)
            $file->add_lines_after("$key = $state_value\n", "/^[^#]/");
    }

    ///////////////////////////////////////////////////////////////////////////////
    // V A L I D A T I O N   M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////

    /**
     * Validation routine for port.
     *
     * @param integer $port $port
     *
     * @return string error message if port is invalid
     */

    public function validate_port($port)
    {
        clearos_profile(__METHOD__, __LINE__);

        if (( ! empty($port)) and (! Network_Utils::is_valid_port($port)))
            return lang('kopano_port_invalid');
    }
}
